@@ -180,31 +180,35 @@ class Dnac:
         return data['response']
 
     def getPnpDevices(self, **kwargs):
-        try:
+        if 'sn in kwargs':
             serialNumber = kwargs['sn']
-        except:
+        else:
             serialNumber = None
-        url = "https://" + self.ip + ":" + self.port + \
-            "/dna/intent/api/v1/onboarding/pnp-device?state=Unclaimed"
+
+        endpoint = "onboarding/pnp-device"
         payload = {}
         headers = {
             'x-auth-token': self.authToken
         }
-        response = requests.request(
-            "GET", url, headers=headers, data=payload, verify=self.verifySSL, timeout=self.timeout)
-        data = json.loads(response.text)
+ #       response = requests.request(
+ #           "GET", url, headers=headers, data=payload, verify=self.verifySSL, timeout=self.timeout)
+ #       data = json.loads(response.text)
 
-        if serialNumber == None:
+
+        response = restcall('GET', self, endpoint)
+        data = response
+
+        if serialNumber is None:
             return data
+
         else:
             for device in data:
                 if serialNumber in device['deviceInfo']['serialNumber']:
-                    ret = device
-            try:
-                return device
-            except:
-                raise ezDNACError('Device with serial number' +
-                                  serialNumber + ' not found in pnp.')
+                    return device
+
+            # If sn was set, but not found:
+            raise ezDNACError('Device with serial number' +
+                               serialNumber + ' not found in pnp.')
 
     def getInventoryDevies(self, **kwargs):
 
@@ -241,8 +245,10 @@ class Dnac:
             data = response['response']
 
             for device in data:
-                if serialNumber in device['serialNumber']:
-                    return device
+                if 'serialNumber' in device:
+                    if device['serialNumber'] is not None:
+                        if serialNumber in device['serialNumber']:
+                            return device
 
         # If hostname is used
         elif hostname is not None:
